pub struct NetworkOptions {
pub graph: Option<GraphOptions>,
pub use_shortest_path: Option<bool>,
}Fields
graph: Option<GraphOptions>The network topology graph
use_shortest_path: Option<bool>When routing packets, follow the shortest path rather than following a direct edge between nodes. If false, the network graph is required to be complete.
Implementations
Sourceimpl NetworkOptions
impl NetworkOptions
Sourcepub fn with_defaults(self, default: Self) -> Self
pub fn with_defaults(self, default: Self) -> Self
Replace unset (None) values of base with values from default.