pub struct DescriptorTable { /* private fields */ }Expand description
Map of file handles to file descriptors. Typically owned by a
Thread.
Implementations
Sourceimpl DescriptorTable
impl DescriptorTable
pub fn new() -> Self
Sourcepub fn get(&self, idx: DescriptorHandle) -> Option<&Descriptor>
pub fn get(&self, idx: DescriptorHandle) -> Option<&Descriptor>
Get the descriptor at idx, if any.
Sourcepub fn get_mut(&mut self, idx: DescriptorHandle) -> Option<&mut Descriptor>
pub fn get_mut(&mut self, idx: DescriptorHandle) -> Option<&mut Descriptor>
Get the descriptor at idx, if any.
Sourcepub fn register_descriptor(
&mut self,
desc: Descriptor,
) -> Result<DescriptorHandle, Descriptor>
pub fn register_descriptor( &mut self, desc: Descriptor, ) -> Result<DescriptorHandle, Descriptor>
Register a descriptor and return its fd handle. Equivalent to
register_descriptor_with_min_fd(desc, 0). If the
descriptor could not be added, the descriptor is returned in the Err.
Sourcepub fn register_descriptor_with_min_fd(
&mut self,
desc: Descriptor,
min_fd: DescriptorHandle,
) -> Result<DescriptorHandle, Descriptor>
pub fn register_descriptor_with_min_fd( &mut self, desc: Descriptor, min_fd: DescriptorHandle, ) -> Result<DescriptorHandle, Descriptor>
Register a descriptor and return its fd handle. If the descriptor could not be added, the
descriptor is returned in the Err.
Sourcepub fn register_descriptor_with_fd(
&mut self,
desc: Descriptor,
new_fd: DescriptorHandle,
) -> Option<Descriptor>
pub fn register_descriptor_with_fd( &mut self, desc: Descriptor, new_fd: DescriptorHandle, ) -> Option<Descriptor>
Register a descriptor with a given fd handle and return the descriptor that it replaced.
Sourcepub fn deregister_descriptor(
&mut self,
fd: DescriptorHandle,
) -> Option<Descriptor>
pub fn deregister_descriptor( &mut self, fd: DescriptorHandle, ) -> Option<Descriptor>
Deregister the descriptor with the given fd handle and return it.
Sourcepub fn remove_all(&mut self) -> impl Iterator<Item = Descriptor>
pub fn remove_all(&mut self) -> impl Iterator<Item = Descriptor>
Remove and return all descriptors.
Sourcepub fn remove_range(
&mut self,
range: impl RangeBounds<DescriptorHandle>,
) -> impl Iterator<Item = Descriptor>
pub fn remove_range( &mut self, range: impl RangeBounds<DescriptorHandle>, ) -> impl Iterator<Item = Descriptor>
Remove and return all descriptors in the range. If you want to remove all descriptors, you
should use remove_all.
pub fn iter(&self) -> impl Iterator<Item = (&DescriptorHandle, &Descriptor)>
pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (&DescriptorHandle, &mut Descriptor)>