pub struct FileState(/* private fields */);Expand description
Flags representing the state of a file.
Listeners can subscribe to state changes using FileRefMut::add_listener (or similar
methods on SocketRefMut, Pipe, etc).
When setting these flags on a file, they should match the result of an epoll-wait on the
file. For example if an epoll-wait on a file would return EPOLLIN, then the file should
have the READABLE state flag. If an epoll-wait would not return EPOLLIN, then the file
should not have the READABLE state flag.
Implementations
Sourceimpl FileState
impl FileState
pub const NONE: Self
use FileState::empty()
Sourcepub const ACTIVE: Self
pub const ACTIVE: Self
Has been initialized and it is now OK to unblock any plugin waiting on a particular state.
This is a legacy C state and is deprecated.
Sourcepub const FUTEX_WAKEUP: Self
pub const FUTEX_WAKEUP: Self
A wakeup operation occurred on a futex.
Sourcepub const CHILD_EVENT: Self
pub const CHILD_EVENT: Self
A child process had an event reportable via e.g. waitpid.
Sourcepub const SOCKET_ALLOWING_CONNECT: Self
pub const SOCKET_ALLOWING_CONNECT: Self
A listening socket is allowing connections. Only applicable to connection-oriented unix sockets.
Sourceimpl FileState
impl FileState
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.