pub struct FileId { /* private fields */ }Expand description
Stable identifier for a file, which we use to look up record locks. Remains valid as long as the file has links in the file system and/or there are open file descriptors to the file.