pub struct ZombieProcess { /* private fields */ }Expand description
A process that has exited.
Implementations
Sourceimpl ZombieProcess
impl ZombieProcess
pub fn exit_status(&self) -> ExitStatus
Sourcepub fn reaper<'host>(
&self,
host: &'host Host,
) -> Option<impl Deref<Target = RootedRc<RootedRefCell<Process>>> + 'host>
pub fn reaper<'host>( &self, host: &'host Host, ) -> Option<impl Deref<Target = RootedRc<RootedRefCell<Process>>> + 'host>
Process that can reap this zombie process, if any.
Sourcepub fn exit_siginfo(&self, exit_signal: Signal) -> siginfo_t
pub fn exit_siginfo(&self, exit_signal: Signal) -> siginfo_t
Construct a siginfo containing information about how the process exited.
Used internally to send a signal to the parent process, and by the
waitid syscall handler.
exit_signal is the signal to set in the siginfo_t.