SyscallCondition

Struct SyscallCondition 

pub struct SyscallCondition { /* private fields */ }
An owned syscall condition.

Implementations

Source

impl SyscallCondition

pub unsafe fn consume_from_c(ptr: *mut SysCallCondition) -> Self

“Steal” from a C pointer. i.e. doesn’t increase ref count, but will decrease the ref count when dropped.

Safety

ptr must point to a valid object that will not be accessed by other threads for the lifetime of this object.

pub fn new(trigger: Trigger) -> Self

Constructor.

pub fn new_from_wakeup_time(abs_wakeup_time: EmulatedTime) -> Self

Create a new syscall condition that triggers a wakeup on the calling thread only after the abs_wakeup_time has been reached.

Panics if abs_wakeup_time is before the current emulated time.

pub fn into_inner(self) -> *mut SysCallCondition

“Steal” the inner pointer without unref’ing it.

Methods from Deref<Target = SyscallConditionRefMut<'static>>

pub fn set_active_file(&mut self, file: OpenFile)

pub fn wakeup_for_signal(&mut self, host: &Host, signal: Signal) -> bool

pub fn set_timeout(&mut self, timeout: Option<EmulatedTime>)

Methods from Deref<Target = SyscallConditionRef<'a>>