pub trait IsSend: Send { }Expand description
A trait we can use as a compile-time check to make sure that an object is Send.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait IsSend: Send { }A trait we can use as a compile-time check to make sure that an object is Send.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".