pub trait IsSync: Sync { }Expand description
A trait we can use as a compile-time check to make sure that an object is Sync.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait IsSync: Sync { }A trait we can use as a compile-time check to make sure that an object is Sync.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".